@@ -861,7 +861,7 @@ class Scatter(Figure):
 class ScatterMatrix(Figure):
     """ ScatterMatrix of a list of Samples. """
 
-    _template_name = "scatter_matrix_template"
+    _template_name = "multiplot_template"
 
     def __init__(self, elements: List[Sample] = None, axes: List[str] = None, point_style: PointStyle = None,
                  surface_style: SurfaceStyle = None, width: int = 750, height: int = 400, name: str = ""):
@@ -882,7 +882,14 @@ class ScatterMatrix(Figure):
         self.axes = axes
         self.point_style = point_style
         self.surface_style = surface_style
-        super().__init__(width=width, height=height, type_="scattermatrix", name=name)
+        self.plots = self._build_multiplot()
+        self.initial_view_on = True
+        super().__init__(width=width, height=height, type_="multiplot", name=name)
+
+    def _build_multiplot(self):
+        sample_attributes = self.elements[0].values.keys()
+        return [Histogram(col) if row == col else Scatter(row, col)
+                for row in sample_attributes for col in sample_attributes]
 
 
 class Arc2D(PlotDataObject):
@@ -1229,7 +1236,7 @@ class Histogram(Figure):
         self.graduation_nb = graduation_nb
         self.edge_style = edge_style
         self.surface_style = surface_style
-        super().__init__(width=width, height=height, type_='histogram', name=name)
+        super().__init__(width=width, height=height, type_='frame', name=name)
 
 
 class MultiplePlots(Figure):
